/*
* Copyright (c) 2003, University of Maryland 
* Copyright (c) 2003, Center for Satellite and Hybrid Communication Networks 
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without 
* modification, are permitted provided that the following conditions 
* are met:
*
*   * Redistributions of source code must retain the above copyright notice, 
*     this list of conditions,the authors and the following disclaimer.
*   * Redistributions in binary form must reproduce the above copyright notice,
*     this list of conditions,the authors and the following disclaimer in
*     the documentation and/or other materials provided with the distribution.
*   * Neither the name of the University of Maryland/Center for Satellite
*     and Hybrid Communication Networks nor the names of its 
*     contributors may be used to endorse or promote products derived from 
*     this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
* POSSIBILITY OF SUCH DAMAGE.
*
*/

/* Authors: 
*     Jonathan Polley (jpolley@isr.umd.edu),
*     Dionysus Blazakis (dblaze@isr.umd.edu),
*     Jonathan McGee (mcgee@isr.umd.edu),
*     Daniel Rusk (ruskd@isr.umd.edu),
*     Manish Karir (karir@isr.umd.edu)
*/

#ifndef CHIP_DATA_STRUCT_H
#define CHIP_DATA_STRUCT_H

/* chip_data_struct.h
 * only to be included if you are actually using the gtk stuff that's in
 * a chip data, not just passing one around. */

#include <gtk/gtk.h>
#include "table.h"
#include "func_data.h"

struct _chip_data {
    int id;

    /* asm view */
    GtkWidget *textview_code;
    /* C view */
    GtkWidget *textview_source;

    /* selection of C file option menu */
    GtkWidget *cfile_select;
    /* and the menu it pops up */
    GtkWidget *cfile_select_menu;
    
    table_t *cfile_to_textbuffers;
    table_t *cfile_index_to_textbuffers;

    GtkWidget *treeview_regs;
    GtkWidget *treeview_stack;
    GtkWidget *treeview_locals;
    GtkWidget *treeview_globals;

    GtkWidget *textview_events;
    GtkWidget *textview_debug;
    GtkWidget *treeview_break;
    GtkWidget *treeview_watch;

    GtkWidget *treeview_break_popup;
    GtkWidget *treeview_watch_popup;
    
    GtkWidget *vpaned;
    GtkWidget *hpaned;

    GtkTextBuffer * code;

    GtkListStore * regs;
    GtkListStore * stack;
    GtkListStore * locals;
    GtkListStore * globals;

    GtkTextBuffer * events;
    GtkTextBuffer * debug;

    GtkListStore * breakp;
    GtkListStore * watchp;

    table_t * addr_to_text_line;
    table_t * text_line_to_addr;
    table_t * addr_to_c_line;
    table_t * c_line_to_addr;

    table_t * functions;
    table_t * global_addr;
    table_t * global_by_name;
    table_t * global_by_id;

    /* a table to store attributes(size, members, etc. ) of various types */
    table_t * types;

    struct func_data *curr_func;

    long int stack_pointer;
    long int status_register;

    /* disassembly view breakpoints */
    table_t *asm_break;
    /* C source view breakpoints */
    table_t *source_break;
    /* automatic breakpoints (for C stepping) */
    table_t *auto_break;
};

#endif
